aboutsummaryrefslogtreecommitdiffstats
path: root/examples/network/blockingfortuneclient.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/network/blockingfortuneclient.py')
-rw-r--r--examples/network/blockingfortuneclient.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/network/blockingfortuneclient.py b/examples/network/blockingfortuneclient.py
index 028c05c8f..4ee0ce622 100644
--- a/examples/network/blockingfortuneclient.py
+++ b/examples/network/blockingfortuneclient.py
@@ -40,14 +40,14 @@
##
#############################################################################
-"""PySide2 port of the network/blockingfortunclient example from Qt v5.x, originating from PyQt"""
+"""PySide6 port of the network/blockingfortunclient example from Qt v5.x, originating from PyQt"""
-from PySide2.QtCore import (Signal, QDataStream, QMutex, QMutexLocker,
+from PySide6.QtCore import (Signal, QDataStream, QMutex, QMutexLocker,
QThread, QWaitCondition)
-from PySide2.QtGui import QIntValidator
-from PySide2.QtWidgets import (QApplication, QDialogButtonBox, QGridLayout,
+from PySide6.QtGui import QIntValidator
+from PySide6.QtWidgets import (QApplication, QDialogButtonBox, QGridLayout,
QLabel, QLineEdit, QMessageBox, QPushButton, QWidget)
-from PySide2.QtNetwork import (QAbstractSocket, QHostAddress, QNetworkInterface,
+from PySide6.QtNetwork import (QAbstractSocket, QHostAddress, QNetworkInterface,
QTcpSocket)